==> bpp_iplweb-202012.51-py3-none-any.whl: raport_slotow/forms.py <==
from crispy_forms.helper import FormHelper
from crispy_forms_foundation.layout import (
    Layout,
    Fieldset,
    Row,
    Column,
    ButtonHolder,
    Submit,
)
from dal import autocomplete
from django import forms
from django.core.exceptions import ValidationError
from django.utils import timezone

from bpp.models import Autor
from bpp.util import formdefaults_html_after, formdefaults_html_before


def year_last_month():
    now = timezone.now().date()
    if now.month >= 2:
        return now.year
    return now.year - 1


OUTPUT_FORMATS = [
    ("html", "wyświetl w przeglądarce"),
    ("xlsx", "Microsoft Excel (XLSX)"),
]


class AutorRaportSlotowForm(forms.Form):
    obiekt = forms.ModelChoiceField(
        label="Autor",
        queryset=Autor.objects.all(),
        widget=autocomplete.ModelSelect2(url="bpp:public-autor-autocomplete"),
    )

    od_roku = forms.IntegerField(initial=year_last_month)
    do_roku = forms.IntegerField(initial=year_last_month)

    _export = forms.ChoiceField(
        label="Format wyjściowy", choices=OUTPUT_FORMATS, required=True
    )

    def clean(self):
        if "od_roku" in self.cleaned_data and "do_roku" in self.cleaned_data:
            if self.cleaned_data["od_roku"] > self.cleaned_data["do_roku"]:
                raise ValidationError(
                    {
                        "od_roku": ValidationError(
                            'Pole musi być większe lub równe jak pole "Do roku".'
                        )
                    }
                )

    def __init__(self, *args, **kwargs):
        super(AutorRaportSlotowForm, self).__init__(*args, **kwargs)

        self.helper = FormHelper()
        self.helper.form_class = "custom"
        self.helper.form_action = "."
        self.helper.layout = Layout(
            Fieldset(
                "Wybierz parametry",
                formdefaults_html_before(self),
                Row(Column("obiekt", css_class="large-12 small-12")),
                Row(
                    Column("od_roku", css_class="large-6 small-6"),
                    Column("do_roku", css_class="large-6 small-6"),
                ),
                Row(Column("_export")),
                formdefaults_html_after(self),
            ),
            ButtonHolder(
                Submit(
                    "submit",
                    "Pobierz raport",
                    css_id="id_submit",
                    css_class="submit button",
                ),
            ),
        )


class ParametryRaportSlotowUczelniaForm(forms.Form):
    od_roku = forms.IntegerField(initial=year_last_month)
    do_roku = forms.IntegerField(initial=year_last_month)

    maksymalny_slot = forms.IntegerField(
        label="Maksymalny slot", initial=1, min_value=1
    )

    dziel_na_jednostki_i_wydzialy = forms.BooleanField(
        label="Dziel na jednostki i wydziały", initial=True, required=False
    )

    _export = forms.ChoiceField(
        label="Format wyjściowy", choices=OUTPUT_FORMATS, required=True
    )

    def clean(self):
        if "od_roku" in self.cleaned_data and "do_roku" in self.cleaned_data:
            if self.cleaned_data["od_roku"] > self.cleaned_data["do_roku"]:
                raise ValidationError(
                    {
                        "od_roku": ValidationError(
                            'Pole musi być większe lub równe jak pole "Do roku".'
                        )
                    }
                )

    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.form_class = "custom"
        self.helper.form_action = "."
        self.helper.layout = Layout(
            Fieldset(
                "Wybierz parametry",
                formdefaults_html_before(self),
                Row(
                    Column("od_roku", css_class="large-6 small-6"),
                    Column("do_roku", css_class="large-6 small-6"),
                ),
                Row(Column("maksymalny_slot", css_class="large-12 small-12")),
                Row(Column("dziel_na_jednostki_i_wydzialy")),
                Row(Column("_export")),
                formdefaults_html_after(self),
            ),
            ButtonHolder(
                Submit(
                    "submit",
                    "Pobierz raport",
                    css_id="id_submit",
                    css_class="submit button",
                ),
            ),
        )

        super(ParametryRaportSlotowUczelniaForm, self).__init__(*args, **kwargs)


class ParametryRaportSlotowEwaluacjaForm(forms.Form):
    rok = forms.IntegerField(initial=year_last_month, min_value=2017)

    _export = forms.ChoiceField(
        label="Format wyjściowy", choices=OUTPUT_FORMATS, required=True
    )

    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.form_class = "custom"
        self.helper.form_action = "."
        self.helper.layout = Layout(
            Fieldset(
                "Wybierz parametry",
                formdefaults_html_before(self),
                Row(Column("rok", css_class="large-6 small-6"),),
                Row(Column("_export")),
                formdefaults_html_after(self),
            ),
            ButtonHolder(
                Submit(
                    "submit",
                    "Pobierz raport",
                    css_id="id_submit",
                    css_class="submit button",
                ),
            ),
        )

        super(ParametryRaportSlotowEwaluacjaForm, self).__init__(*args, **kwargs)

==> bpp_iplweb-202101.53-py3-none-any.whl: raport_slotow/forms.py <==
from crispy_forms.helper import FormHelper
from crispy_forms_foundation.layout import (
    ButtonHolder,
    Column,
    Fieldset,
    Layout,
    Row,
    Submit,
)
from dal import autocomplete
from django import forms
from django.core.exceptions import ValidationError
from . import const

from bpp.models import Autor, Uczelnia
from bpp.util import formdefaults_html_after, formdefaults_html_before, year_last_month

OUTPUT_FORMATS = [
    ("html", "wyświetl w przeglądarce"),
    ("xlsx", "Microsoft Excel (XLSX)"),
]


class AutorRaportSlotowForm(forms.Form):
    obiekt = forms.ModelChoiceField(
        label="Autor",
        queryset=Autor.objects.all(),
        widget=autocomplete.ModelSelect2(url="bpp:public-autor-autocomplete"),
    )

    od_roku = forms.IntegerField(initial=year_last_month, min_value=2016)
    do_roku = forms.IntegerField(initial=Uczelnia.objects.do_roku_default)

    minimalny_pk = forms.IntegerField(label="Minimalna wartość PK pracy", initial=0)

    dzialanie = forms.ChoiceField(
        label="Wygeneruj",
        choices=(
            (
                const.DZIALANIE_WSZYSTKO,
                "prace autora z punktacją dla dziedzin za dany okres",
            ),
            (const.DZIALANIE_SLOT, "zbierz najlepsze prace do zadanej wielkości slotu"),
        ),
        initial="wszystko",
        widget=forms.RadioSelect,
    )

    slot = forms.IntegerField(
        label="Zadana wielkość slotu",
        required=False,
    )

    _export = forms.ChoiceField(
        label="Format wyjściowy", choices=OUTPUT_FORMATS, required=True
    )

    def clean(self):
        if "od_roku" in self.cleaned_data and "do_roku" in self.cleaned_data:
            if self.cleaned_data["od_roku"] > self.cleaned_data["do_roku"]:
                raise ValidationError(
                    {
                        "od_roku": ValidationError(
                            'Pole musi być większe lub równe jak pole "Do roku".',
                            code="od_do_zle",
                        )
                    }
                )

        if (
            self.cleaned_data["dzialanie"] == const.DZIALANIE_WSZYSTKO
            and "slot" in self.cleaned_data
            and self.cleaned_data["slot"] is not None
        ):
            raise ValidationError(
                {
                    "slot": ValidationError(
                        "Gdy chcesz wygenerować wszystkie prace tego autora, pozostaw pole 'Slot' puste. ",
                        code="nie_podawaj_gdy_wszystko",
                    )
                }
            )

        if self.cleaned_data["dzialanie"] == const.DZIALANIE_SLOT and (
            "slot" not in self.cleaned_data
            or ("slot" in self.cleaned_data and self.cleaned_data["slot"] is None)
            or (
                "slot" in self.cleaned_data
                and self.cleaned_data["slot"] is not None
                and self.cleaned_data["slot"] <= 0
            )
        ):
            raise ValidationError(
                {
                    "slot": ValidationError(
                        "Podaj wartość slota do którego chcesz zbierać prace. Wartość musi być większa od zera. ",
                        code="podawaj_gdy_slot",
                    )
                }
            )

    def __init__(self, *args, **kwargs):
        super(AutorRaportSlotowForm, self).__init__(*args, **kwargs)

        self.helper = FormHelper()
        self.helper.form_class = "custom"
        self.helper.form_action = "."
        self.helper.layout = Layout(
            Fieldset(
                "Wybierz parametry",
                formdefaults_html_before(self),
                Row(Column("obiekt", css_class="large-12 small-12")),
                Row(Column("dzialanie", css_class="large-12 small-12")),
                Row(Column("slot", css_class="large-12 small-12")),
                Row(
                    Column("od_roku", css_class="large-6 small-6"),
                    Column("do_roku", css_class="large-6 small-6"),
                ),
                Row(Column("minimalny_pk")),
                Row(Column("_export")),
                formdefaults_html_after(self),
            ),
            ButtonHolder(
                Submit(
                    "submit",
                    "Pobierz raport",
                    css_id="id_submit",
                    css_class="submit button",
                ),
            ),
        )


class ParametryRaportSlotowUczelniaForm(forms.Form):
    od_roku = forms.IntegerField(initial=year_last_month)
    do_roku = forms.IntegerField(initial=Uczelnia.objects.do_roku_default)

    maksymalny_slot = forms.IntegerField(
        label="Maksymalny slot", initial=1, min_value=1
    )

    dziel_na_jednostki_i_wydzialy = forms.BooleanField(
        label="Dziel na jednostki i wydziały", initial=True, required=False
    )

    _export = forms.ChoiceField(
        label="Format wyjściowy", choices=OUTPUT_FORMATS, required=True
    )

    def clean(self):
        if "od_roku" in self.cleaned_data and "do_roku" in self.cleaned_data:
            if self.cleaned_data["od_roku"] > self.cleaned_data["do_roku"]:
                raise ValidationError(
                    {
                        "od_roku": ValidationError(
                            'Pole musi być większe lub równe jak pole "Do roku".'
                        )
                    }
                )

    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.form_class = "custom"
        self.helper.form_action = "."
        self.helper.layout = Layout(
            Fieldset(
                "Wybierz parametry",
                formdefaults_html_before(self),
                Row(
                    Column("od_roku", css_class="large-6 small-6"),
                    Column("do_roku", css_class="large-6 small-6"),
                ),
                Row(Column("maksymalny_slot", css_class="large-12 small-12")),
                Row(Column("dziel_na_jednostki_i_wydzialy")),
                Row(Column("_export")),
                formdefaults_html_after(self),
            ),
            ButtonHolder(
                Submit(
                    "submit",
                    "Pobierz raport",
                    css_id="id_submit",
                    css_class="submit button",
                ),
            ),
        )

        super(ParametryRaportSlotowUczelniaForm, self).__init__(*args, **kwargs)


class ParametryRaportSlotowEwaluacjaForm(forms.Form):
    rok = forms.IntegerField(initial=Uczelnia.objects.do_roku_default, min_value=2017)

    _export = forms.ChoiceField(
        label="Format wyjściowy", choices=OUTPUT_FORMATS, required=True
    )

    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.form_class = "custom"
        self.helper.form_action = "."
        self.helper.layout = Layout(
            Fieldset(
                "Wybierz parametry",
                formdefaults_html_before(self),
                Row(
                    Column("rok", css_class="large-6 small-6"),
                ),
                Row(Column("_export")),
                formdefaults_html_after(self),
            ),
            ButtonHolder(
                Submit(
                    "submit",
                    "Pobierz raport",
                    css_id="id_submit",
                    css_class="submit button",
                ),
            ),
        )

        super(ParametryRaportSlotowEwaluacjaForm, self).__init__(*args, **kwargs)
